@@ -9,14 +9,17 @@ import pkg_resources
 
 
 def prinfPath():
-    print("path is " + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
+    print("!!!" + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
 
-def prinfPathOS:
+def prinfABC():
+    print("ABC")
+
+def prinfLsd():
+    print("lsd" + "abc")
+
+def prinfOs():
     print(os.path.dirname(os.path.realpath(__file__)))
 
-def prinfPathABC():
-    print("ABCDEFG")
-
 #打码函数
 # size为打码的方块大小
 def drawMask(x_start,x_end,y_start,y_end,size,img):
@@ -47,7 +50,6 @@ def faceRecognizer(filepath):
         # "haarcascade_frontalface_default.xml"
         # blurredface_sts_test.haarcascade.haarcascade_frontalface_default
         parent+"haarcascades/haarcascade_frontalface_default.xml"
-
     )
     classifier_alt_tree = cv2.CascadeClassifier(
         # "haarcascades/haarcascade_frontalface_alt_tree.xml"
